/*
 * include/mach/hardware.h
 *
 * This file is licensed under the terms of the GNU General Public
 * License version 2.  This program is licensed "as is" without any
 * warranty of any kind, whether express or implied.
 */

#ifndef __ASM_ARCH_HARDWARE_H
#define __ASM_ARCH_HARDWARE_H

#include "armadaxp.h"

//#define pcibios_assign_all_busses()	1

#define PCIMEM_BASE			PEX0_MEM_PHYS_BASE /* mem base for VGA */


#endif
